@@ -4,6 +4,7 @@ import os
 import sys
 import traceback
 
+import redis
 from python_terraform import Terraform
 from redistimeseries.client import Client
 
@@ -24,6 +25,7 @@ from redisbench_admin.utils.benchmark_config import (
     prepare_benchmark_definitions,
     check_required_modules,
     results_dict_kpi_check,
+    extract_redis_configuration_parameters,
 )
 from redisbench_admin.utils.redisgraph_benchmark_go import (
     spin_up_standalone_remote_redis,
@@ -353,6 +355,11 @@ def run_remote_command_logic(args):
             # after we've created the env, even on error we should always teardown
             # in case of some unexpected error we fail the test
             try:
+
+                redis_configuration_parameters = extract_redis_configuration_parameters(
+                    benchmark_config, "dbconfig"
+                )
+
                 # setup Redis
                 spin_up_standalone_remote_redis(
                     benchmark_config,
@@ -363,6 +370,7 @@ def run_remote_command_logic(args):
                     remote_module_file,
                     remote_dataset_file,
                     dirname,
+                    redis_configuration_parameters,
                 )
                 module_names, artifact_versions = extract_artifact_version_remote(
                     server_public_ip, server_plaintext_port, username, private_key
@@ -389,20 +397,11 @@ def run_remote_command_logic(args):
                         redisbenchmark_go_link,
                     )
                 if "tsbs_" in benchmark_tool:
-                    remote_tool_link = "/tmp/{}".format(benchmark_tool)
-                    tool_link = (
-                        "https://s3.amazonaws.com/benchmarks.redislabs/"
-                        + "redistimeseries/tools/tsbs/{}_linux_amd64".format(
-                            benchmark_tool
-                        )
-                    )
-
-                    queries_file_link = None
-                    for entry in benchmark_config["clientconfig"]:
-                        if "parameters" in entry:
-                            for parameter in entry["parameters"]:
-                                if "file" in parameter:
-                                    queries_file_link = parameter["file"]
+                    (
+                        queries_file_link,
+                        remote_tool_link,
+                        tool_link,
+                    ) = extract_tsbs_extra_links(benchmark_config, benchmark_tool)
 
                     setup_remote_benchmark_tool_requirements_tsbs(
                         client_public_ip,
@@ -525,31 +524,47 @@ def run_remote_command_logic(args):
                         tf_github_repo,
                         tf_triggering_env,
                     )
-                    rts.redis.sadd(testcases_setname, test_name)
-                    rts.incrby(
-                        tsname_project_total_success,
-                        1,
-                        timestamp=start_time_ms,
-                        labels=get_project_ts_tags(
-                            tf_github_org,
-                            tf_github_repo,
-                            deployment_type,
-                            tf_triggering_env,
-                        ),
-                    )
+                    try:
+                        rts.redis.sadd(testcases_setname, test_name)
+                        rts.incrby(
+                            tsname_project_total_success,
+                            1,
+                            timestamp=start_time_ms,
+                            labels=get_project_ts_tags(
+                                tf_github_org,
+                                tf_github_repo,
+                                deployment_type,
+                                tf_triggering_env,
+                            ),
+                        )
+                    except redis.exceptions.ResponseError as e:
+                        logging.warning(
+                            "Error while updating secondary data structures {}. ".format(
+                                e.__str__()
+                            )
+                        )
+                        pass
             except:
                 if args.push_results_redistimeseries:
-                    rts.incrby(
-                        tsname_project_total_failures,
-                        1,
-                        timestamp=start_time_ms,
-                        labels=get_project_ts_tags(
-                            tf_github_org,
-                            tf_github_repo,
-                            deployment_type,
-                            tf_triggering_env,
-                        ),
-                    )
+                    try:
+                        rts.incrby(
+                            tsname_project_total_failures,
+                            1,
+                            timestamp=start_time_ms,
+                            labels=get_project_ts_tags(
+                                tf_github_org,
+                                tf_github_repo,
+                                deployment_type,
+                                tf_triggering_env,
+                            ),
+                        )
+                    except redis.exceptions.ResponseError as e:
+                        logging.warning(
+                            "Error while updating secondary data structures {}. ".format(
+                                e.__str__()
+                            )
+                        )
+                        pass
                 return_code |= 1
                 logging.critical(
                     "Some unexpected exception was caught "
@@ -569,6 +584,21 @@ def run_remote_command_logic(args):
     exit(return_code)
 
 
+def extract_tsbs_extra_links(benchmark_config, benchmark_tool):
+    remote_tool_link = "/tmp/{}".format(benchmark_tool)
+    tool_link = (
+        "https://s3.amazonaws.com/benchmarks.redislabs/"
+        + "redistimeseries/tools/tsbs/{}_linux_amd64".format(benchmark_tool)
+    )
+    queries_file_link = None
+    for entry in benchmark_config["clientconfig"]:
+        if "parameters" in entry:
+            for parameter in entry["parameters"]:
+                if "file" in parameter:
+                    queries_file_link = parameter["file"]
+    return queries_file_link, remote_tool_link, tool_link
+
+
 def get_test_s3_bucket_path(s3_bucket_name, test_name, tf_github_org, tf_github_repo):
     s3_bucket_path = "{github_org}/{github_repo}/results/{test_name}/".format(
         github_org=tf_github_org,
@@ -596,7 +626,7 @@ def redistimeseries_results_logic(
     exporter_timemetric_path, metrics = merge_default_and_config_metrics(
         benchmark_config, default_metrics, exporter_timemetric_path
     )
-    common_exporter_logic(
+    per_version_time_series_dict, per_branch_time_series_dict = common_exporter_logic(
         deployment_type,
         exporter_timemetric_path,
         metrics,
@@ -609,6 +639,7 @@ def redistimeseries_results_logic(
         tf_triggering_env,
         artifact_version,
     )
+    return per_version_time_series_dict, per_branch_time_series_dict
 
 
 def merge_default_and_config_metrics(
